==> haskell-criterion-measurement-0.2.3.0-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion-measurement
version:              0.2.3.0
visibility:           public
id:                   criterion-measurement-0.2.3.0-378RW5OXLFq5GF7tHz4vZg
key:                  criterion-measurement-0.2.3.0-378RW5OXLFq5GF7tHz4vZg
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:
    Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/criterion
synopsis:             Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.

category:             Development, Performance, Testing, Benchmarking
abi:                  cecacd4b3f23db7cf36282a6384c6ca5
exposed:              True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/criterion-measurement-0.2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/criterion-measurement-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/criterion-measurement-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion-measurement
hs-libraries:         HScriterion-measurement-0.2.3.0-378RW5OXLFq5GF7tHz4vZg
depends:
    aeson-2.1.2.1-JZeWX2s1eQL7Ta3HF3w6fW base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4 binary-0.8.9.1
    containers-0.6.7 deepseq-1.4.8.1 ghc-prim-0.10.0
    vector-0.13.2.0-JoP5POFPMLsLn1of7TvjGI

haddock-interfaces:
    /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock

haddock-html:         /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-measurement-0.2.3.0-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion-measurement
version:              0.2.3.0
visibility:           public
id:                   criterion-measurement-0.2.3.0-6IGzRHTPjZ36J46oAMMyxH
key:                  criterion-measurement-0.2.3.0-6IGzRHTPjZ36J46oAMMyxH
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:
    Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/criterion
synopsis:             Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.

category:             Development, Performance, Testing, Benchmarking
abi:                  1a8cf57aabc2737aea2c3c2f58ba6ad7
exposed:              True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/criterion-measurement-0.2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/criterion-measurement-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/criterion-measurement-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion-measurement
hs-libraries:         HScriterion-measurement-0.2.3.0-6IGzRHTPjZ36J46oAMMyxH
depends:
    aeson-2.1.2.1-6DouAcLayfd1cKsM4PdlxR base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4 binary-0.8.9.1
    containers-0.6.7 deepseq-1.4.8.1 ghc-prim-0.10.0
    vector-0.13.2.0-8Ien1418VpU5tGTMA2qRu7

haddock-interfaces:
    /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock

haddock-html:         /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
